"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateDocumentationJsonToFile = exports.getDocumentationJsonPath = exports.generateDocumentationJson = void 0;
// tslint:disable-next-line:no-import-side-effect
require("reflect-metadata");
const RoutingControllers = require("@benjd90/routing-controllers");
const n9_node_conf_1 = require("@neo9/n9-node-conf");
const n9_node_log_1 = require("@neo9/n9-node-log");
const appRootDir = require("app-root-dir");
const ClassValidator = require("class-validator");
const class_validator_jsonschema_1 = require("class-validator-jsonschema");
const fs = require("fs");
const path_1 = require("path");
const RCOpenApi = require("routing-controllers-openapi");
const typedi_1 = require("typedi");
const N9NodeRouting = require("./models/routing");
const options_1 = require("./options");
const utils_1 = require("./utils");
function generateDocumentationJson(n9NodeRoutingOptions, serverAlreadyStarted = true, defaultValuesAreAlreadySet = false, 
// eslint-disable-next-line global-require,import/no-dynamic-require
packageJson = require((0, path_1.join)(appRootDir.get(), 'package.json'))) {
    if (defaultValuesAreAlreadySet) {
        const environment = (0, utils_1.getEnvironment)();
        (0, options_1.applyDefaultValuesOnOptions)(n9NodeRoutingOptions, environment, packageJson.name);
    }
    RoutingControllers.useContainer(typedi_1.Container);
    ClassValidator.useContainer(typedi_1.Container);
    typedi_1.Container.set(n9_node_log_1.N9Log, n9NodeRoutingOptions.log);
    const baseOpenApiSpec = {
        info: {
            description: packageJson.description,
            title: packageJson.name,
            version: packageJson.version,
        },
    };
    if (!serverAlreadyStarted) {
        typedi_1.Container.set(N9NodeRouting.Options, n9NodeRoutingOptions);
        RoutingControllers.createExpressServer(n9NodeRoutingOptions.http.routingController);
    }
    const routesStorage = RoutingControllers.getMetadataArgsStorage();
    const schemas = (0, class_validator_jsonschema_1.validationMetadatasToSchemas)({
        refPointerPrefix: '#/components/schemas/',
    });
    const additionalProperties = { components: { schemas }, ...baseOpenApiSpec };
    const spec = RCOpenApi.routingControllersToSpec(routesStorage, n9NodeRoutingOptions.http.routingController, additionalProperties);
    return spec;
}
exports.generateDocumentationJson = generateDocumentationJson;
function getDocumentationJsonPath(options) {
    return ((options.openapi && options.openapi.jsonPath) ||
        (0, path_1.join)(appRootDir.get(), 'openapi-documentation.json'));
}
exports.getDocumentationJsonPath = getDocumentationJsonPath;
function generateDocumentationJsonToFile(optionsParams = {}) {
    const confOptions = (0, options_1.getLoadingConfOptions)(optionsParams);
    const conf = (0, n9_node_conf_1.default)(confOptions);
    // eslint-disable-next-line @typescript-eslint/no-var-requires,global-require,import/no-dynamic-require
    const packageJson = require((0, path_1.join)(appRootDir.get(), 'package.json'));
    const environment = (0, utils_1.getEnvironment)();
    const options = (0, options_1.mergeOptionsAndConf)(optionsParams, conf.n9NodeRoutingOptions);
    (0, options_1.applyDefaultValuesOnOptions)(options, environment, packageJson.name);
    if (options.openapi && options.openapi.isEnabled) {
        const path = getDocumentationJsonPath(options);
        const spec = generateDocumentationJson(options, false, true);
        options.log.debug(`OpenAPI documentation generated. Saving to a file...`);
        fs.writeFileSync(path, JSON.stringify(spec, null, 2));
        options.log.info(`OpenAPI documentation generated at : ${path}`);
        return path;
    }
}
exports.generateDocumentationJsonToFile = generateDocumentationJsonToFile;
//# sourceMappingURL=generate-documentation-json.js.map