"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const glob = require("glob-promise");
const path_1 = require("path");
exports.default = async (path, log, firstSequentialInitFileNames) => {
    const initFiles = await glob('**/*.init.+(ts|js)', { cwd: path });
    if (firstSequentialInitFileNames) {
        for (const firstSequentialInitFileName of firstSequentialInitFileNames) {
            const matchingInitFileIndex = initFiles.findIndex((initFile) => initFile.includes(firstSequentialInitFileName));
            if (matchingInitFileIndex !== -1) {
                const moduleName = initFiles[matchingInitFileIndex].split('/').slice(-2)[0];
                log.info(`Init module ${moduleName}`);
                // eslint-disable-next-line @typescript-eslint/no-var-requires,global-require,import/no-dynamic-require
                let module = require((0, path_1.join)(path, initFiles[matchingInitFileIndex]));
                module = module.default ? module.default : module;
                await module(log);
                log.debug(`End init module ${moduleName}`);
                initFiles.splice(matchingInitFileIndex, 1);
            }
        }
    }
    await Promise.all(initFiles.map(async (file) => {
        const moduleName = file.split('/').slice(-2)[0];
        try {
            log.info(`Init module ${moduleName}`);
            // eslint-disable-next-line @typescript-eslint/no-var-requires,global-require,import/no-dynamic-require
            let module = require((0, path_1.join)(path, file));
            module = module.default ? module.default : module;
            await module(log);
            log.debug(`End init module ${moduleName}`);
        }
        catch (e) {
            log.error(`Error while initializing ${moduleName}`, { errString: JSON.stringify(e) });
            throw e;
        }
    }));
};
//# sourceMappingURL=initialise-modules.js.map