"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ErrorHandler = void 0;
const routing_controllers_1 = require("@benjd90/routing-controllers");
const n9_node_log_1 = require("@neo9/n9-node-log");
const Sentry = require("@sentry/node");
const fast_safe_stringify_1 = require("fast-safe-stringify");
const typedi_1 = require("typedi");
const N9NodeRouting = require("../models/routing");
function removePropertiesRecursively(obj, keys) {
    if (!obj)
        return;
    if (obj instanceof Array) {
        obj.forEach((item) => {
            removePropertiesRecursively(item, keys);
        });
    }
    else if (typeof obj === 'object') {
        Object.getOwnPropertyNames(obj).forEach((key) => {
            if (keys.includes(key))
                delete obj[key];
            else
                removePropertiesRecursively(obj[key], keys);
        });
    }
}
let ErrorHandler = class ErrorHandler {
    constructor(logger, n9NodeRoutingOptions) {
        this.logger = logger;
        this.n9NodeRoutingOptions = n9NodeRoutingOptions;
        if (this.n9NodeRoutingOptions.sentry) {
            this.sentryErrorHandler = Sentry.Handlers.errorHandler(this.n9NodeRoutingOptions.sentry.errorHandlerOptions);
        }
        if (this.n9NodeRoutingOptions.apm?.type === 'newRelic') {
            // eslint-disable-next-line @typescript-eslint/no-var-requires,global-require
            this.newRelicNoticeError = require('newrelic').noticeError;
        }
    }
    error(error, request, response, next) {
        const status = error.status || error.httpCode || 500;
        let code = 'unspecified-error';
        if (error.code) {
            code = error.code;
        }
        else if (error.name && error.name !== 'Error') {
            code = error.name;
        }
        else if (error.message) {
            code = error.message;
        }
        const context = error.context || error.errors || {};
        // remove stack properties to avoid leak
        removePropertiesRecursively(context, ['stack']);
        error.code = code;
        if (status < 500) {
            this.logger.warn(code, { errString: (0, fast_safe_stringify_1.default)(error) });
        }
        else {
            this.logger.error(code, { errString: (0, fast_safe_stringify_1.default)(error) });
        }
        if (this.sentryErrorHandler) {
            this.sentryErrorHandler(error, request, response, next);
        }
        if (this.newRelicNoticeError) {
            try {
                this.newRelicNoticeError(error, { errString: (0, fast_safe_stringify_1.default)(error) });
            }
            catch (e) {
                this.logger.warn(`Error while sending error to newrelic`, {
                    errString: (0, fast_safe_stringify_1.default)(e),
                });
            }
        }
        response.status(status);
        response.json({
            code,
            status,
            context,
        });
    }
};
exports.ErrorHandler = ErrorHandler;
exports.ErrorHandler = ErrorHandler = __decorate([
    (0, typedi_1.Service)(),
    (0, routing_controllers_1.Middleware)({ type: 'after' }),
    __metadata("design:paramtypes", [n9_node_log_1.N9Log, N9NodeRouting.Options])
], ErrorHandler);
//# sourceMappingURL=error-handler.interceptor.js.map