"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const glob = require("glob-promise");
const path_1 = require("path");
exports.default = async (path, log, firstSequentialStartFileNames) => {
    const initFiles = await glob('**/*.started.+(ts|js)', { cwd: path });
    if (firstSequentialStartFileNames) {
        for (const firstSequentialStartFileName of firstSequentialStartFileNames) {
            const matchingStartFileIndex = initFiles.findIndex((initFile) => initFile.includes(firstSequentialStartFileName));
            if (matchingStartFileIndex !== -1) {
                const moduleName = initFiles[matchingStartFileIndex].split('/').slice(-2)[0];
                log.info(`Init started module ${moduleName}`);
                // eslint-disable-next-line @typescript-eslint/no-var-requires,global-require,import/no-dynamic-require
                let module = require((0, path_1.join)(path, initFiles[matchingStartFileIndex]));
                module = module.default ? module.default : module;
                await module(log);
                log.debug(`End started module ${moduleName}`);
                initFiles.splice(matchingStartFileIndex, 1);
            }
        }
    }
    await Promise.all(initFiles.map(async (file) => {
        const moduleName = file.split('/').slice(-2)[0];
        try {
            log.info(`Init started module ${moduleName}`);
            // eslint-disable-next-line @typescript-eslint/no-var-requires,global-require,import/no-dynamic-require
            let module = require((0, path_1.join)(path, file));
            module = module.default ? module.default : module;
            await module(log);
            log.debug(`End init started module ${moduleName}`);
        }
        catch (e) {
            log.error(`Error while initializing ${moduleName}`, { errString: JSON.stringify(e) });
            throw e;
        }
    }));
};
//# sourceMappingURL=start-modules.js.map