"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SecretTransformer = exports.SecretType = void 0;
const class_transformer_1 = require("class-transformer");
const _ = require("lodash");
var SecretType;
(function (SecretType) {
    /**
     * Secret is not exposed at all, set to undefined
     */
    SecretType["INVISIBLE"] = "invisible";
    /**
     * Secret is replaced with *** if not nil
     */
    SecretType["OPAQUE"] = "opaque";
    /**
     * If secret is an URI, then the password only is hidden
     */
    SecretType["URI"] = "uri";
})(SecretType || (exports.SecretType = SecretType = {}));
const defaultConfiguration = {
    each: false,
};
class SecretTransformer {
    static GET_TRANSFORMER(secretType = SecretType.INVISIBLE, options = defaultConfiguration) {
        return ({ value, type }) => {
            switch (type) {
                case class_transformer_1.TransformationType.PLAIN_TO_CLASS:
                case class_transformer_1.TransformationType.CLASS_TO_CLASS:
                    return value;
                case class_transformer_1.TransformationType.CLASS_TO_PLAIN:
                    switch (secretType) {
                        case SecretType.OPAQUE:
                            return SecretTransformer.opaqueTransformation(value, options);
                        case SecretType.URI:
                            return SecretTransformer.uriTransformation(value, options);
                        case SecretType.INVISIBLE:
                        default:
                            return;
                    }
                default:
                    throw new Error(`unknown-transformation-type : ${type}`);
            }
        };
    }
    static opaqueTransformation(value, options) {
        if (options.each) {
            return _.map(value, (val) => SecretTransformer.makeOpaque(val));
        }
        return SecretTransformer.makeOpaque(value);
    }
    static makeOpaque(value) {
        return _.isNil(value) ? undefined : '********';
    }
    static uriTransformation(value, options) {
        if (options.each) {
            return _.map(value, (val) => SecretTransformer.maskUri(val));
        }
        return SecretTransformer.maskUri(value);
    }
    static maskUri(value) {
        if (_.isString(value) && this.uriRegex.test(value)) {
            return value.replace(this.uriRegex, '********');
        }
    }
}
exports.SecretTransformer = SecretTransformer;
SecretTransformer.uriRegex = /(?<=:)([^@:]+)(?=@[^@]+$)/;
//# sourceMappingURL=secret.transformer.js.map