/// <reference types="node" />
/// <reference types="node" />
import { N9Log } from '@neo9/n9-node-log';
import { Method, Options as GotOptions } from 'got';
import { IncomingMessage } from 'http';
import { PassThrough } from 'stream';
import { HttpClientOptions } from '../models/routing/options-http-client';
export type N9HttpClientQueryParams = string | Record<string, string | number | boolean | string[] | number[] | boolean[]> | object;
export type N9HttpClientRequestGotOptions = Omit<GotOptions, 'headers' | 'method'>;
export declare class N9HttpClient {
    private readonly logger;
    private maxBodyLengthToLogError;
    private static getUriFromUrlParts;
    private static prepareErrorCodeAndStatus;
    private static alterHeaders;
    private readonly baseClientOptions;
    constructor(logger: N9Log, options?: HttpClientOptions, maxBodyLengthToLogError?: number);
    /**
     * N9HttpClientQueryParams samples : https://github.com/request/request/blob/master/tests/test-qs.js
     */
    get<T>(url: string | string[], queryParams?: N9HttpClientQueryParams, headers?: object, options?: N9HttpClientRequestGotOptions): Promise<T>;
    post<T>(url: string | string[], body?: any, queryParams?: N9HttpClientQueryParams, headers?: object, options?: N9HttpClientRequestGotOptions): Promise<T>;
    put<T>(url: string | string[], body?: any, queryParams?: N9HttpClientQueryParams, headers?: object, options?: N9HttpClientRequestGotOptions): Promise<T>;
    delete<T>(url: string | string[], body?: any, queryParams?: N9HttpClientQueryParams, headers?: object, options?: N9HttpClientRequestGotOptions): Promise<T>;
    options<T>(url: string | string[], queryParams?: N9HttpClientQueryParams, headers?: object, options?: N9HttpClientRequestGotOptions): Promise<T>;
    patch<T>(url: string | string[], body?: any, queryParams?: N9HttpClientQueryParams, headers?: object, options?: N9HttpClientRequestGotOptions): Promise<T>;
    head(url: string | string[], queryParams?: N9HttpClientQueryParams, headers?: object, options?: N9HttpClientRequestGotOptions): Promise<void>;
    request<T>(method: Method, url: string | string[], queryParams?: N9HttpClientQueryParams, headers?: object, body?: any, options?: N9HttpClientRequestGotOptions): Promise<T>;
    raw<T>(url: string | string[], options: GotOptions): Promise<T>;
    requestStream(url: string | string[], options?: Omit<GotOptions, 'isStream' | 'responseType' | 'resolveBodyOnly'>): Promise<{
        incomingMessage: IncomingMessage;
        responseAsStream: PassThrough;
    }>;
    private buildHttpClientOptionsWithDefaults;
}
